# Changelog

## 0.1.0-alpha.14 (2025-04-08)

Full Changelog: [v0.1.0-alpha.13...v0.1.0-alpha.14](https://github.com/Deasie-internal/deasy-labs/compare/v0.1.0-alpha.13...v0.1.0-alpha.14)

### Features

* **api:** api update ([#56](https://github.com/Deasie-internal/deasy-labs/issues/56)) ([ec56fe9](https://github.com/Deasie-internal/deasy-labs/commit/ec56fe960b0742e3b175360c9ab63e346f326f58))

## 0.1.0-alpha.13 (2025-04-08)

Full Changelog: [v0.1.0-alpha.12...v0.1.0-alpha.13](https://github.com/Deasie-internal/deasy-labs/compare/v0.1.0-alpha.12...v0.1.0-alpha.13)

### Features

* add comment to sample notebook ([28534ca](https://github.com/Deasie-internal/deasy-labs/commit/28534cafd1e4fd93b3ad891193aa37fc80446354))
* added deasy select demo ([bc4957a](https://github.com/Deasie-internal/deasy-labs/commit/bc4957a686f98ccd986bbd96c42b8aecd3cb6d21))
* **api:** api update ([#49](https://github.com/Deasie-internal/deasy-labs/issues/49)) ([1a02720](https://github.com/Deasie-internal/deasy-labs/commit/1a027202a4b233bd6a5a8b3bcfb60f38320512aa))
* **api:** api update ([#50](https://github.com/Deasie-internal/deasy-labs/issues/50)) ([5f7913c](https://github.com/Deasie-internal/deasy-labs/commit/5f7913c06c81258dfb6b99cfcd482999e18db2a3))
* **api:** update via SDK Studio ([b98c52a](https://github.com/Deasie-internal/deasy-labs/commit/b98c52a3d69ccaf2dd09530f44f65104f184a3e6))
* **api:** update via SDK Studio ([7f3e990](https://github.com/Deasie-internal/deasy-labs/commit/7f3e99019e417f5d865111639ee6472ec3bb3fff))
* **api:** update via SDK Studio ([66d2f0c](https://github.com/Deasie-internal/deasy-labs/commit/66d2f0ce8361e009d36b06bd86cb080d6d54ed95))
* **api:** update via SDK Studio ([efe25c6](https://github.com/Deasie-internal/deasy-labs/commit/efe25c67a889f201dc9dc26e971f72b5ba5f7345))
* **api:** update via SDK Studio ([e6f6af5](https://github.com/Deasie-internal/deasy-labs/commit/e6f6af54a7a7be126992ce7662c9f48144d04679))
* **api:** update via SDK Studio ([33e752b](https://github.com/Deasie-internal/deasy-labs/commit/33e752bcbd8411c4af2979359dcc31d249299b04))
* **api:** update via SDK Studio ([b43028a](https://github.com/Deasie-internal/deasy-labs/commit/b43028a2db1579a3f615988c4d2cba6cce1c7500))
* **api:** update via SDK Studio ([4c54564](https://github.com/Deasie-internal/deasy-labs/commit/4c54564a3c81b98d7cd563eb7ef18fecabb6486c))
* **api:** update via SDK Studio ([8858ee1](https://github.com/Deasie-internal/deasy-labs/commit/8858ee1a5676f1aa6a80b532bc4edaceaab8b797))
* **api:** update via SDK Studio ([132e5b9](https://github.com/Deasie-internal/deasy-labs/commit/132e5b9e7ac0303cffe6cd383fb6cc21bb525600))
* **api:** update via SDK Studio ([b50741e](https://github.com/Deasie-internal/deasy-labs/commit/b50741e0592fc3b856840e0c6b78d979fc5b6287))
* **api:** update via SDK Studio ([94166ff](https://github.com/Deasie-internal/deasy-labs/commit/94166ff43fd1394404d85ccef620b6d3d538b725))
* **api:** update via SDK Studio ([0523b64](https://github.com/Deasie-internal/deasy-labs/commit/0523b644cbbc0a0a10348bd33dea3f7bf1e3afc4))
* **api:** update via SDK Studio ([581e200](https://github.com/Deasie-internal/deasy-labs/commit/581e2008df2ecad5719ecd1377dd35d7e46f274d))
* **api:** update via SDK Studio ([3eade31](https://github.com/Deasie-internal/deasy-labs/commit/3eade31c34224bb9c0c2d1bcac7c9468b2aeb2ae))
* **api:** update via SDK Studio ([82ace8d](https://github.com/Deasie-internal/deasy-labs/commit/82ace8d0938f0ac4e409a85e2d7c1c31d70f0dc8))
* **api:** update via SDK Studio ([9a337ae](https://github.com/Deasie-internal/deasy-labs/commit/9a337aeb5f42eafa7f5bd8d7a184b4c5a4ee7b25))
* **api:** update via SDK Studio ([#14](https://github.com/Deasie-internal/deasy-labs/issues/14)) ([66051ee](https://github.com/Deasie-internal/deasy-labs/commit/66051ee667644fa5eedf0001227cf67bc55fc12a))
* **api:** update via SDK Studio ([#16](https://github.com/Deasie-internal/deasy-labs/issues/16)) ([1a3f334](https://github.com/Deasie-internal/deasy-labs/commit/1a3f33418ec0272b6f87f3d3da029e3a2f414951))
* **api:** update via SDK Studio ([#18](https://github.com/Deasie-internal/deasy-labs/issues/18)) ([72ed361](https://github.com/Deasie-internal/deasy-labs/commit/72ed361420b177662d1896959ce2ecfc54c499f2))
* **api:** update via SDK Studio ([#21](https://github.com/Deasie-internal/deasy-labs/issues/21)) ([b26e436](https://github.com/Deasie-internal/deasy-labs/commit/b26e436f1f316b952c37c6b1080b8751e22625f3))
* **api:** update via SDK Studio ([#24](https://github.com/Deasie-internal/deasy-labs/issues/24)) ([15e9bcc](https://github.com/Deasie-internal/deasy-labs/commit/15e9bccf096371b70d1a0447745302e1059f67c4))
* **api:** update via SDK Studio ([#29](https://github.com/Deasie-internal/deasy-labs/issues/29)) ([519b7d9](https://github.com/Deasie-internal/deasy-labs/commit/519b7d9dc0569ba91b7958db0ccb8136b92bab15))
* **api:** update via SDK Studio ([#3](https://github.com/Deasie-internal/deasy-labs/issues/3)) ([0c3a16a](https://github.com/Deasie-internal/deasy-labs/commit/0c3a16a50bfe3aa158fe210061a90ea2d72053d0))
* **api:** update via SDK Studio ([#31](https://github.com/Deasie-internal/deasy-labs/issues/31)) ([7620e32](https://github.com/Deasie-internal/deasy-labs/commit/7620e32f115850dc8a76e9e85b539c9df3244538))
* **api:** update via SDK Studio ([#40](https://github.com/Deasie-internal/deasy-labs/issues/40)) ([3f52e65](https://github.com/Deasie-internal/deasy-labs/commit/3f52e65fe4e86d4aabfce051faf61854b680c866))
* **api:** update via SDK Studio ([#41](https://github.com/Deasie-internal/deasy-labs/issues/41)) ([641ec46](https://github.com/Deasie-internal/deasy-labs/commit/641ec46e9c941818e903e3d4a0121adac62e5820))
* **api:** update via SDK Studio ([#47](https://github.com/Deasie-internal/deasy-labs/issues/47)) ([dfe0f03](https://github.com/Deasie-internal/deasy-labs/commit/dfe0f034538b5ab403c863650f3bf3b97a03e9a3))
* **api:** update via SDK Studio ([#48](https://github.com/Deasie-internal/deasy-labs/issues/48)) ([46cf671](https://github.com/Deasie-internal/deasy-labs/commit/46cf6718d810366e7212ded3b7dd4398b1002856))
* **api:** update via SDK Studio ([#5](https://github.com/Deasie-internal/deasy-labs/issues/5)) ([686a0b0](https://github.com/Deasie-internal/deasy-labs/commit/686a0b05edd57252e44c281e3a6dd991bb8d306b))
* **api:** update via SDK Studio ([#6](https://github.com/Deasie-internal/deasy-labs/issues/6)) ([3f67510](https://github.com/Deasie-internal/deasy-labs/commit/3f6751067f5cada73bbcde433489cbec33935014))
* **api:** update via SDK Studio ([#7](https://github.com/Deasie-internal/deasy-labs/issues/7)) ([c43daf1](https://github.com/Deasie-internal/deasy-labs/commit/c43daf1d7e8dfcd9fdb2a30f3b5ef25ed451681e))
* **api:** update via SDK Studio ([#8](https://github.com/Deasie-internal/deasy-labs/issues/8)) ([e0795f0](https://github.com/Deasie-internal/deasy-labs/commit/e0795f03b801004a8352da778188dfe367655337))
* **api:** update via SDK Studio ([#9](https://github.com/Deasie-internal/deasy-labs/issues/9)) ([4a0f598](https://github.com/Deasie-internal/deasy-labs/commit/4a0f598400bc186cf792969969611fa9cf38f880))
* rye linting ([52902e7](https://github.com/Deasie-internal/deasy-labs/commit/52902e74be7c8f4cb347cf6f36e2bd54aad7909f))


### Bug Fixes

* **ci:** ensure pip is always available ([#4](https://github.com/Deasie-internal/deasy-labs/issues/4)) ([4f27385](https://github.com/Deasie-internal/deasy-labs/commit/4f2738580b4027948e4ba23bdd5ae1a300f349cf))
* **ci:** remove publishing patch ([#5](https://github.com/Deasie-internal/deasy-labs/issues/5)) ([1f40da1](https://github.com/Deasie-internal/deasy-labs/commit/1f40da1a278fc28584a942441d0ca04698e6aea3))
* **types:** handle more discriminated union shapes ([#3](https://github.com/Deasie-internal/deasy-labs/issues/3)) ([00e2157](https://github.com/Deasie-internal/deasy-labs/commit/00e2157348836775e7b1c3732c96758cc7e70b39))


### Chores

* fix typos ([#34](https://github.com/Deasie-internal/deasy-labs/issues/34)) ([8a6e1b8](https://github.com/Deasie-internal/deasy-labs/commit/8a6e1b848e0202f1f18d038db74cd49cd7b3779f))
* go live ([#1](https://github.com/Deasie-internal/deasy-labs/issues/1)) ([c891c49](https://github.com/Deasie-internal/deasy-labs/commit/c891c495f0f8c345faa215b67eb0f1119a8258e6))
* go live ([#1](https://github.com/Deasie-internal/deasy-labs/issues/1)) ([948fc70](https://github.com/Deasie-internal/deasy-labs/commit/948fc706c6adec7d84adc8ee27af6332203e522a))
* go live ([#46](https://github.com/Deasie-internal/deasy-labs/issues/46)) ([3ff0402](https://github.com/Deasie-internal/deasy-labs/commit/3ff0402c7bc1417d8e3d59b55e9f26c1681d384f))
* go live ([#7](https://github.com/Deasie-internal/deasy-labs/issues/7)) ([e83cf87](https://github.com/Deasie-internal/deasy-labs/commit/e83cf87c3caf8be4feed53c80df3ec325bee0b7e))
* go live ([#8](https://github.com/Deasie-internal/deasy-labs/issues/8)) ([22d5bd1](https://github.com/Deasie-internal/deasy-labs/commit/22d5bd130af9fecb8f79ed69aa8e08972b5af9d6))
* **internal:** remove trailing character ([#38](https://github.com/Deasie-internal/deasy-labs/issues/38)) ([b6311b4](https://github.com/Deasie-internal/deasy-labs/commit/b6311b46b485ac3654633b99f8bec24844563df4))
* sync repo ([fb007f9](https://github.com/Deasie-internal/deasy-labs/commit/fb007f99e60f89082f611655ca6f1cfe779673e3))
* sync repo ([a887ec1](https://github.com/Deasie-internal/deasy-labs/commit/a887ec12eedf04970fce9ed7e112064e3533a6a1))
* update SDK settings ([e0e36fc](https://github.com/Deasie-internal/deasy-labs/commit/e0e36fcd377c92497679d5ed35e402638e8cbcfb))
* update SDK settings ([#11](https://github.com/Deasie-internal/deasy-labs/issues/11)) ([aa3148d](https://github.com/Deasie-internal/deasy-labs/commit/aa3148db8a8553e0c9d3b7d136e93d722a0f1287))


### Documentation

* swap examples used in readme ([#39](https://github.com/Deasie-internal/deasy-labs/issues/39)) ([0084df8](https://github.com/Deasie-internal/deasy-labs/commit/0084df8e55de86b232e77d7d9099c7c99cac31b3))

## 0.1.0-alpha.12 (2025-04-08)

Full Changelog: [v0.1.0-alpha.11...v0.1.0-alpha.12](https://github.com/Deasie-internal/deasy-labs/compare/v0.1.0-alpha.11...v0.1.0-alpha.12)

### Features

* **api:** api update ([#49](https://github.com/Deasie-internal/deasy-labs/issues/49)) ([364d3a0](https://github.com/Deasie-internal/deasy-labs/commit/364d3a0722e48286fa991a1a0db48eaf6b75a8e4))
* **api:** api update ([#50](https://github.com/Deasie-internal/deasy-labs/issues/50)) ([1ec4356](https://github.com/Deasie-internal/deasy-labs/commit/1ec43563a48914deedf72020025e5175f8fff173))
* **api:** update via SDK Studio ([#47](https://github.com/Deasie-internal/deasy-labs/issues/47)) ([f3d8662](https://github.com/Deasie-internal/deasy-labs/commit/f3d866254cb4f15e715bb3bcc0708f10876de176))
* **api:** update via SDK Studio ([#48](https://github.com/Deasie-internal/deasy-labs/issues/48)) ([9ea463b](https://github.com/Deasie-internal/deasy-labs/commit/9ea463bae0f776d21de8c9f8afa0045583f1bda2))


### Chores

* go live ([#46](https://github.com/Deasie-internal/deasy-labs/issues/46)) ([39fa9da](https://github.com/Deasie-internal/deasy-labs/commit/39fa9dabfb1fe47fe44b59617fb353361023ad96))
* sync repo ([fe8e3e6](https://github.com/Deasie-internal/deasy-labs/commit/fe8e3e673d8edf32fc4914154f18ca29b84024aa))

## 0.1.0-alpha.11 (2025-03-30)

Full Changelog: [v0.1.0-alpha.10...v0.1.0-alpha.11](https://github.com/Deasie-internal/deasy-python/compare/v0.1.0-alpha.10...v0.1.0-alpha.11)

### Features

* added deasy select demo ([bc4957a](https://github.com/Deasie-internal/deasy-python/commit/bc4957a686f98ccd986bbd96c42b8aecd3cb6d21))
* rye linting ([52902e7](https://github.com/Deasie-internal/deasy-python/commit/52902e74be7c8f4cb347cf6f36e2bd54aad7909f))


### Chores

* fix typos ([#34](https://github.com/Deasie-internal/deasy-python/issues/34)) ([8a6e1b8](https://github.com/Deasie-internal/deasy-python/commit/8a6e1b848e0202f1f18d038db74cd49cd7b3779f))

## 0.1.0-alpha.10 (2025-03-26)

Full Changelog: [v0.1.0-alpha.9...v0.1.0-alpha.10](https://github.com/Deasie-internal/deasy-python/compare/v0.1.0-alpha.9...v0.1.0-alpha.10)

### Features

* **api:** update via SDK Studio ([#31](https://github.com/Deasie-internal/deasy-python/issues/31)) ([b62985b](https://github.com/Deasie-internal/deasy-python/commit/b62985b44ea8a147a8b79193db6af9353e5a30f4))

## 0.1.0-alpha.9 (2025-03-20)

Full Changelog: [v0.1.0-alpha.8...v0.1.0-alpha.9](https://github.com/Deasie-internal/deasy-python/compare/v0.1.0-alpha.8...v0.1.0-alpha.9)

### Features

* **api:** update via SDK Studio ([#29](https://github.com/Deasie-internal/deasy-python/issues/29)) ([3adf7a5](https://github.com/Deasie-internal/deasy-python/commit/3adf7a5d4f22c8194cdffc6fb8f8bc34a2f2090b))

## 0.1.0-alpha.8 (2025-03-19)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/Deasie-internal/deasy-python/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Features

* **api:** update via SDK Studio ([#24](https://github.com/Deasie-internal/deasy-python/issues/24)) ([79c3f8b](https://github.com/Deasie-internal/deasy-python/commit/79c3f8b483999a72d5ab530c788d34cef675b7cc))

## 0.1.0-alpha.7 (2025-03-19)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/Deasie-internal/deasy-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** update via SDK Studio ([#21](https://github.com/Deasie-internal/deasy-python/issues/21)) ([450b2a1](https://github.com/Deasie-internal/deasy-python/commit/450b2a1a4d1a2e427af038b522d4b54ce47ae786))

## 0.1.0-alpha.6 (2025-03-19)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/Deasie-internal/deasy-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** update via SDK Studio ([#18](https://github.com/Deasie-internal/deasy-python/issues/18)) ([0dc0f8a](https://github.com/Deasie-internal/deasy-python/commit/0dc0f8a30e66c80be57fe98896e53d127cf0c2a0))

## 0.1.0-alpha.5 (2025-03-19)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/Deasie-internal/deasy-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** update via SDK Studio ([#14](https://github.com/Deasie-internal/deasy-python/issues/14)) ([dbe0ee7](https://github.com/Deasie-internal/deasy-python/commit/dbe0ee794d2f1d02a80bbc089abf194842771eb1))
* **api:** update via SDK Studio ([#16](https://github.com/Deasie-internal/deasy-python/issues/16)) ([3c432b2](https://github.com/Deasie-internal/deasy-python/commit/3c432b249bdaed409a8bada3adc65cce8021bfbe))

## 0.1.0-alpha.4 (2025-03-19)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/Deasie-internal/deasy-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Chores

* update SDK settings ([#11](https://github.com/Deasie-internal/deasy-python/issues/11)) ([195c387](https://github.com/Deasie-internal/deasy-python/commit/195c387bd63c355cfa7167011440a78caf756d65))

## 0.1.0-alpha.3 (2025-03-19)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/Deasie-internal/deasy-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** update via SDK Studio ([9c3c885](https://github.com/Deasie-internal/deasy-python/commit/9c3c88558703efb2b07d6d21ed7553ed6ad21a76))


### Chores

* go live ([#8](https://github.com/Deasie-internal/deasy-python/issues/8)) ([0654b0b](https://github.com/Deasie-internal/deasy-python/commit/0654b0b47b418fc3aad4804e47698dba20639a7a))

## 0.1.0-alpha.2 (2025-03-19)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/Deasie-internal/deasy-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([#5](https://github.com/Deasie-internal/deasy-python/issues/5)) ([ac17290](https://github.com/Deasie-internal/deasy-python/commit/ac17290340da1c482a52a411f6855889cc07a2a6))

## 0.1.0-alpha.1 (2025-03-19)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/Deasie-internal/deasy-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([7f3e990](https://github.com/Deasie-internal/deasy-python/commit/7f3e99019e417f5d865111639ee6472ec3bb3fff))
* **api:** update via SDK Studio ([66d2f0c](https://github.com/Deasie-internal/deasy-python/commit/66d2f0ce8361e009d36b06bd86cb080d6d54ed95))
* **api:** update via SDK Studio ([efe25c6](https://github.com/Deasie-internal/deasy-python/commit/efe25c67a889f201dc9dc26e971f72b5ba5f7345))
* **api:** update via SDK Studio ([e6f6af5](https://github.com/Deasie-internal/deasy-python/commit/e6f6af54a7a7be126992ce7662c9f48144d04679))
* **api:** update via SDK Studio ([33e752b](https://github.com/Deasie-internal/deasy-python/commit/33e752bcbd8411c4af2979359dcc31d249299b04))
* **api:** update via SDK Studio ([b43028a](https://github.com/Deasie-internal/deasy-python/commit/b43028a2db1579a3f615988c4d2cba6cce1c7500))
* **api:** update via SDK Studio ([4c54564](https://github.com/Deasie-internal/deasy-python/commit/4c54564a3c81b98d7cd563eb7ef18fecabb6486c))
* **api:** update via SDK Studio ([8858ee1](https://github.com/Deasie-internal/deasy-python/commit/8858ee1a5676f1aa6a80b532bc4edaceaab8b797))
* **api:** update via SDK Studio ([132e5b9](https://github.com/Deasie-internal/deasy-python/commit/132e5b9e7ac0303cffe6cd383fb6cc21bb525600))
* **api:** update via SDK Studio ([b50741e](https://github.com/Deasie-internal/deasy-python/commit/b50741e0592fc3b856840e0c6b78d979fc5b6287))
* **api:** update via SDK Studio ([94166ff](https://github.com/Deasie-internal/deasy-python/commit/94166ff43fd1394404d85ccef620b6d3d538b725))
* **api:** update via SDK Studio ([0523b64](https://github.com/Deasie-internal/deasy-python/commit/0523b644cbbc0a0a10348bd33dea3f7bf1e3afc4))
* **api:** update via SDK Studio ([581e200](https://github.com/Deasie-internal/deasy-python/commit/581e2008df2ecad5719ecd1377dd35d7e46f274d))
* **api:** update via SDK Studio ([3eade31](https://github.com/Deasie-internal/deasy-python/commit/3eade31c34224bb9c0c2d1bcac7c9468b2aeb2ae))
* **api:** update via SDK Studio ([82ace8d](https://github.com/Deasie-internal/deasy-python/commit/82ace8d0938f0ac4e409a85e2d7c1c31d70f0dc8))
* **api:** update via SDK Studio ([9a337ae](https://github.com/Deasie-internal/deasy-python/commit/9a337aeb5f42eafa7f5bd8d7a184b4c5a4ee7b25))
* **api:** update via SDK Studio ([#3](https://github.com/Deasie-internal/deasy-python/issues/3)) ([787656f](https://github.com/Deasie-internal/deasy-python/commit/787656ff2bda8cdf25c313b5fe9ee8541e966130))
* **api:** update via SDK Studio ([#6](https://github.com/Deasie-internal/deasy-python/issues/6)) ([3f67510](https://github.com/Deasie-internal/deasy-python/commit/3f6751067f5cada73bbcde433489cbec33935014))
* **api:** update via SDK Studio ([#7](https://github.com/Deasie-internal/deasy-python/issues/7)) ([c43daf1](https://github.com/Deasie-internal/deasy-python/commit/c43daf1d7e8dfcd9fdb2a30f3b5ef25ed451681e))
* **api:** update via SDK Studio ([#8](https://github.com/Deasie-internal/deasy-python/issues/8)) ([e0795f0](https://github.com/Deasie-internal/deasy-python/commit/e0795f03b801004a8352da778188dfe367655337))
* **api:** update via SDK Studio ([#9](https://github.com/Deasie-internal/deasy-python/issues/9)) ([4a0f598](https://github.com/Deasie-internal/deasy-python/commit/4a0f598400bc186cf792969969611fa9cf38f880))


### Bug Fixes

* **ci:** ensure pip is always available ([#4](https://github.com/Deasie-internal/deasy-python/issues/4)) ([4f27385](https://github.com/Deasie-internal/deasy-python/commit/4f2738580b4027948e4ba23bdd5ae1a300f349cf))
* **ci:** remove publishing patch ([#5](https://github.com/Deasie-internal/deasy-python/issues/5)) ([1f40da1](https://github.com/Deasie-internal/deasy-python/commit/1f40da1a278fc28584a942441d0ca04698e6aea3))
* **types:** handle more discriminated union shapes ([#3](https://github.com/Deasie-internal/deasy-python/issues/3)) ([00e2157](https://github.com/Deasie-internal/deasy-python/commit/00e2157348836775e7b1c3732c96758cc7e70b39))


### Chores

* go live ([#1](https://github.com/Deasie-internal/deasy-python/issues/1)) ([a2277ec](https://github.com/Deasie-internal/deasy-python/commit/a2277ecb13e67006d3fd4c37eee167d8b9b11c92))
* go live ([#1](https://github.com/Deasie-internal/deasy-python/issues/1)) ([948fc70](https://github.com/Deasie-internal/deasy-python/commit/948fc706c6adec7d84adc8ee27af6332203e522a))
* go live ([#7](https://github.com/Deasie-internal/deasy-python/issues/7)) ([e83cf87](https://github.com/Deasie-internal/deasy-python/commit/e83cf87c3caf8be4feed53c80df3ec325bee0b7e))
* sync repo ([a887ec1](https://github.com/Deasie-internal/deasy-python/commit/a887ec12eedf04970fce9ed7e112064e3533a6a1))
* update SDK settings ([e0e36fc](https://github.com/Deasie-internal/deasy-python/commit/e0e36fcd377c92497679d5ed35e402638e8cbcfb))
